@@ -1,4 +1,5 @@
 "Test helper functions and base test cases."
+from __future__ import unicode_literals
 
 import random
 import string
@@ -13,7 +14,7 @@ class ScribblerDataTestCase(TestCase):
     "Base test case for creating scribbler models."
 
     def get_random_string(self, length=10):
-        return u''.join(random.choice(string.ascii_letters) for x in xrange(length))
+        return ''.join(random.choice(string.ascii_letters) for x in range(length))
 
     def create_scribble(self, **kwargs):
         "Factory method for creating Scribbles."
